@@ -1,14 +1,18 @@
 =head1 NAME
-
-DatabaseSettings - read in an XML file of settings and return a hash with the values
+Bio::MLST::DatabaseSettings
 
 =head1 SYNOPSIS
+Read in an XML file of settings and return a hash with the values
+
+=head1 DESCRIPTION
 
 use Bio::MLST::DatabaseSettings;
 my $database_settings = Bio::MLST::DatabaseSettings->new(
   filename     => 'filename'
 );
 $database_settings->settings;
+=head1 CONTACT
+path-help@sanger.ac.uk
 =cut
 
 package Bio::MLST::DatabaseSettings;
